@@ -12,7 +12,9 @@
 makeSchafferN2Function = function() {
   makeSingleObjectiveFunction(
     name = "Schaffer Function N. 2",
+    id = "schaffer02_2d",
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       a = x[1]^2
       b = x[2]^2
       0.5 + (sin(a - b)^2 - 0.5) / (1 + 0.001 * (a + b))^2
@@ -31,6 +33,6 @@ makeSchafferN2Function = function() {
 }
 
 class(makeSchafferN2Function) = c("function", "smoof_generator")
-attr(makeSchafferN2Function, "name") = c("Schaffer Function N. 2")
+attr(makeSchafferN2Function, "name") = c("Schaffer N. 2")
 attr(makeSchafferN2Function, "type") = c("single-objective")
-attr(makeSchafferN2Function, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "unimodal")
+attr(makeSchafferN2Function, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "unimodal")
